//+------------------------------------------------------------------+
//
//										AllSymbolsExport_v0.1_scr.mq4
//
//+------------------------------------------------------------------+
//
//	script for extracting all symbols visible in >Market Watch< panel
//	and save in CSV files qoutes from all of them
//

#property show_inputs

extern int     BarsToExport   = 500;   // The amount of bars to be exported
extern string  valueSeparator = ",";   // symbol separating values in CSV files
extern int     TimeFrame      = 1440;  // use standart TF enumeration constants 1,5,15,30,60,240,1440,10080,43200

//+------------------------------------------------------------------+

int symbolCount;

//+------------------------------------------------------------------+
int start()
{
	Comment(""); // clear any comments on main window
      
   if (IsConnected() == false) {
      Alert ("Connect to the server first!");
      return (0);
   }
	
	int fh = FileOpenHistory("symbols.sel",FILE_BIN|FILE_READ);
	if(fh>0) {
		symbolCount = (FileSize(fh)-4) / 0x80;
		string temp, symbolList[];		
		ArrayResize(symbolList,symbolCount);
		int i=0;
		FileSeek(fh,4,SEEK_SET);
		while(!IsStopped()) {
			temp = FileReadString(fh,12);
			if(FileIsEnding(fh)) break;
			symbolList[i] = StringSubstr(temp,0,StringFind(temp,"\x00",0));
			i++;
			FileSeek(fh,0x80-12,SEEK_CUR);
		}
		FileClose(fh);
      
      // check for out of range >TimeFrame< input
      if ( (TimeFrame<0) || (TimeFrame>43200) ) {
         Alert("   Use standart TimeFrame enumeration!   ");
         return(0);
      }
      
		for(int k=0; k<symbolCount; k++)
			write_data(symbolList[k]);
		
	}
	return(0);
}

//+------------------------------------------------------------------+
void write_data(string tmpSymbol) {
   int handle;
   string nameData = tmpSymbol+"_"+TimeFrame+".csv";
   int TimeFrame;
   string tBarTime;
   string tHigh, tLow, tOpen, tClose, tVolume;
   string Content;
   int decPrecision;
   
   if ( StringFind(tmpSymbol,"JPY", 0)>-1    || 
         StringFind(tmpSymbol,"BRENT", 0)>-1 || 
         StringFind(tmpSymbol,"XAG", 0)>-1   || 
         StringFind(tmpSymbol,"XAU", 0)>-1)
      decPrecision = 2;
   else
      decPrecision = 4;
   
  handle = FileOpen(nameData, FILE_CSV|FILE_WRITE, ',');
  if(handle < 1) {
    Comment("Creation of "+nameData+" failed. Error #", GetLastError());
    return(0);
  }
  FileWrite(handle, "DATE","OPEN","HIGH","LOW","CLOSE","VOLUME");   // heading
  for (int j=BarsToExport-1; j>=0; j--) {
         tBarTime = TimeToStr(iTime(tmpSymbol, TimeFrame, j));
         tHigh = DoubleToStr(iHigh(tmpSymbol, TimeFrame, j),decPrecision);
         tLow = DoubleToStr(iLow(tmpSymbol, TimeFrame, j),decPrecision);
         tOpen = DoubleToStr(iOpen(tmpSymbol, TimeFrame, j),decPrecision);
         tClose = DoubleToStr(iClose(tmpSymbol, TimeFrame, j),decPrecision);
         tVolume = DoubleToStr(iVolume(tmpSymbol, TimeFrame, j),0);
         
         Content = StringConcatenate(tBarTime, valueSeparator,
                                    tHigh, valueSeparator,
                                    tLow, valueSeparator,
                                    tOpen, valueSeparator,
                                    tClose, valueSeparator,
                                    tVolume);
            
    FileWrite(handle, Content);
  }
  FileClose(handle);
  
  Comment("\n", symbolCount , " files has been created.");
  
  return(0);
}
//+------------------------------------------------------------------+